@@ -14,8 +14,8 @@
 ;; Homepage: https://www.github.com/clojure-emacs/cider
 ;; Keywords: languages, clojure, cider
 ;;
-;; Package-Version: 20251022.1407
-;; Package-Revision: 9b3f84645b1e
+;; Package-Version: 20251105.925
+;; Package-Revision: 8e3091e8c427
 ;; Package-Requires: (
 ;;     (emacs "27")
 ;;     (clojure-mode "5.19")
@@ -104,10 +104,10 @@
 (require 'sesman)
 (require 'package)
 
-(defconst cider-version "1.20.0-snapshot"
+(defconst cider-version "1.20.0"
   "The current version of CIDER.")
 
-(defconst cider-codename "Skiathos"
+(defconst cider-codename "Lanzarote"
   "Codename used to denote stable releases.")
 
 (defcustom cider-lein-command
